#!/usr/bin/env bash

setup_file(){
  load "$PWD/tests/integration/helpers/common"
  _common_setup
  _add_server
  _new_app
}

teardown_file(){
  _rm_app
  _rm_server
}

setup(){
  load "$PWD/tests/integration/helpers/common"
  _common_setup
}

teardown(){
  # https://github.com/bats-core/bats-core/issues/383#issuecomment-738628888
  if [[ -z "${BATS_TEST_COMPLETED}" ]]; then
    _undeploy_app
  fi
}

@test "validate app argument" {
  run $ABRA app run
  assert_failure
  assert_output --partial 'no app provided'

  run $ABRA app run DOESNTEXIST
  assert_failure
  assert_output --partial 'cannot find app'
}

@test "error if missing service" {
  run $ABRA app run "$TEST_APP_DOMAIN"
  assert_failure
  assert_output --partial 'no <service> provided'

  run $ABRA app run "$TEST_APP_DOMAIN" app
  assert_failure
  assert_output --partial 'no <args> provided'
}

# bats test_tags=slow
@test "error if service doesn't exist" {
  _deploy_app

  run $ABRA app run "$TEST_APP_DOMAIN" DOESNTEXIST ls
  assert_failure
  assert_output --partial 'no containers matching'

  _undeploy_app
}

# bats test_tags=slow
@test "run command" {
  _deploy_app

  run $ABRA app run "$TEST_APP_DOMAIN" app ls /
  assert_success
  assert_output --partial 'root'

  _undeploy_app
}
