#!/usr/bin/env bash

setup_file(){
  load "$PWD/tests/integration/helpers/common"
  _common_setup
  _add_server
  _new_app
}

teardown_file(){
  _rm_app
  _rm_server
}

setup(){
  load "$PWD/tests/integration/helpers/common"
  _common_setup
}

teardown(){
  # https://github.com/bats-core/bats-core/issues/383#issuecomment-738628888
  if [[ -z "${BATS_TEST_COMPLETED}" ]]; then
    _undeploy_app
  fi
}

@test "validate app argument" {
  run $ABRA app version
  assert_failure
  assert_output --partial 'no app provided'

  run $ABRA app version DOESNTEXIST
  assert_failure
  assert_output --partial 'cannot find app'
}

@test "error if not deployed" {
  run $ABRA app version "$TEST_APP_DOMAIN"
  assert_failure
  assert_output --partial 'is not deployed'
}

# bats test_tags=slow
@test "error if version unknown" {
  run sed -i '/coop-cloud.${STACK_NAME}.version=.*/d' "$ABRA_DIR/recipes/$TEST_RECIPE/compose.yml"
  assert_success

  run $ABRA app deploy "$TEST_APP_DOMAIN" \
    --no-input --no-converge-checks --chaos
  assert_success

  run $ABRA app version "$TEST_APP_DOMAIN"
  assert_failure
  assert_output --partial 'failed to determine'

  _checkout_recipe "$TEST_RECIPE"
  _undeploy_app
}

# bats test_tags=slow
@test "error if no version in catalogue" {
  _deploy_app

  run $ABRA app version "$TEST_APP_DOMAIN"
  assert_failure
  assert_output --partial 'could not retrieve deployed version'

  _undeploy_app
}

# bats test_tags=slow
@test "list version" {
  _deploy_app

  latestVersion=$(git -C "$ABRA_DIR/recipes/$TEST_RECIPE" git tag | tail -n 1)
  refute [ -z "$latestVersion" ];

  run $ABRA app version "$TEST_APP_DOMAIN"
  assert_success
  assert_output --partial "$latestVersion"

  _undeploy_app
}
